import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { queryBuilder } from '@wix/sdk-runtime/query-builder';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixContactsV4ExtendedField from './contacts-v4-extended-field-extended-fields.http.js';
export var FieldDataType;
(function (FieldDataType) {
    /** Accepts strings. */
    FieldDataType["TEXT"] = "TEXT";
    /** Accepts floats. */
    FieldDataType["NUMBER"] = "NUMBER";
    /** Accepts dates formatted as `YYYY-MM-DD`. */
    FieldDataType["DATE"] = "DATE";
    /** Accepts strings. Prepends `https://` if no protocol is included. */
    FieldDataType["URL"] = "URL";
})(FieldDataType || (FieldDataType = {}));
export var FieldType;
(function (FieldType) {
    /** Field is a system field managed by Wix. System fields can't be modified by calling the Update Extended Field method. */
    FieldType["SYSTEM"] = "SYSTEM";
    /** Field is a custom field and can be modified by calling the Update Extended Field method. */
    FieldType["USER_DEFINED"] = "USER_DEFINED";
})(FieldType || (FieldType = {}));
export var SortOrder;
(function (SortOrder) {
    /** Sort by ascending order. */
    SortOrder["ASC"] = "ASC";
    /** Sort by descending order. */
    SortOrder["DESC"] = "DESC";
})(SortOrder || (SortOrder = {}));
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Retrieves a custom field with a specified name, or creates one if it doesn't exist.
 * The number of custom fields is limited to 100.
 *
 * Successful calls to this method always return a field,
 * which can be specified in subsequent calls.
 *
 * To find an existing custom field without potentially creating a new one, call Get Extended Field or
 * Query Extended Fields.
 * @param displayName - Display name to retrieve or create.
 *
 * If an existing custom field is an exact match
 * for the specified display name,
 * the existing field is returned.
 * If not, a new field is created and returned.
 * @param dataType - Type of data the field holds.
 * Ignored if an existing field is an exact match
 * for the specified display name.
 * @public
 * @requiredField dataType
 * @requiredField displayName
 * @permissionId CONTACTS_SCHEMA.MODIFY
 * @permissionScope Manage Contact Extended Fields
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-EX-FIELDS
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @permissionScope Manage Members and Contacts - all permissions
 * @permissionScopeId SCOPE.DC-CONTACTS-MEGA.MANAGE-MEMBERS-CONTACTS
 * @applicableIdentity APP
 * @returns Extended field that was found or created.
 * @fqn com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.FindOrCreateExtendedField
 */
export async function findOrCreateExtendedField(displayName, dataType) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        displayName: displayName,
        dataType: dataType,
    });
    const reqOpts = ambassadorWixContactsV4ExtendedField.findOrCreateExtendedField(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { displayName: '$[0]', dataType: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['displayName', 'dataType']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Retrieves an extended field by the specified extended field key.
 * @public
 * @requiredField key
 * @param key - null
 * @permissionId CONTACTS_SCHEMA.VIEW
 * @permissionScope Manage Bookings Services and Settings
 * @permissionScopeId SCOPE.BOOKINGS.CONFIGURATION
 * @permissionScope Manage Portfolio
 * @permissionScopeId SCOPE.PORTFOLIO.MANAGE-PORTFOLIO
 * @permissionScope Manage Contact Extended Fields
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-EX-FIELDS
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @permissionScope Manage Members and Contacts - all permissions
 * @permissionScopeId SCOPE.DC-CONTACTS-MEGA.MANAGE-MEMBERS-CONTACTS
 * @applicableIdentity APP
 * @returns The specified field.
 * @fqn com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.GetExtendedField
 */
export async function getExtendedField(key) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({ key: key });
    const reqOpts = ambassadorWixContactsV4ExtendedField.getExtendedField(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)?.field;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { key: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['key']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Renames an extended field.
 * @public
 * @requiredField field
 * @requiredField field.displayName
 * @requiredField key
 * @param key - null
 * @param field - null
 * @permissionId CONTACTS_SCHEMA.MODIFY
 * @permissionScope Manage Contact Extended Fields
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-EX-FIELDS
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @permissionScope Manage Members and Contacts - all permissions
 * @permissionScopeId SCOPE.DC-CONTACTS-MEGA.MANAGE-MEMBERS-CONTACTS
 * @applicableIdentity APP
 * @returns Renamed extended field.
 * @fqn com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.UpdateExtendedField
 */
export async function renameExtendedField(key, field) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        field: { ...field, key: key },
    });
    const reqOpts = ambassadorWixContactsV4ExtendedField.updateExtendedField(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)?.field;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: { field: '$[1]' },
            explicitPathsToArguments: { 'field.key': '$[0]' },
            singleArgumentUnchanged: false,
        }, ['key', 'field']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Deletes an extended field.
 *
 * When an extended field is deleted,
 * any contact data stored in the field is also permanently deleted.
 * @param key - Extended field key.
 * @public
 * @requiredField key
 * @permissionId CONTACTS_SCHEMA.MODIFY
 * @permissionScope Manage Contact Extended Fields
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-EX-FIELDS
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @permissionScope Manage Members and Contacts - all permissions
 * @permissionScopeId SCOPE.DC-CONTACTS-MEGA.MANAGE-MEMBERS-CONTACTS
 * @applicableIdentity APP
 * @fqn com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.DeleteExtendedField
 */
export async function deleteExtendedField(key) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({ key: key });
    const reqOpts = ambassadorWixContactsV4ExtendedField.deleteExtendedField(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { key: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['key']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Creates a query to retrieve a list of extended fields.
 *
 * The `queryExtendedFields()` method builds a query to retrieve a list of extended fields and returns an `FieldsQueryBuilder` object.
 *
 * The returned object contains the query definition, which is used to run the query using the `find()` method.
 *
 * You can refine the query by chaining `FieldsQueryBuilder` methods onto the query. `FieldsQueryBuilder` methods enable you to filter, sort, and control the results that `queryExtendedFields()` returns.
 *
 * `queryExtendedFields()` runs with these `FieldsQueryBuilder` defaults, which you can override:
 * - `skip()`
 * - `limit(50)`
 * - `descending('_createdDate')`
 *
 * The following `FieldsQueryBuilder` methods are supported for `queryExtendedFields()`. For a full description of the `Extended Field` object, see the object returned for the `items` property in `FieldsQueryResult`.
 * @public
 * @permissionScope Manage Bookings Services and Settings
 * @permissionScopeId SCOPE.BOOKINGS.CONFIGURATION
 * @permissionScope Manage Portfolio
 * @permissionScopeId SCOPE.PORTFOLIO.MANAGE-PORTFOLIO
 * @permissionScope Manage Contact Extended Fields
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-EX-FIELDS
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @permissionScope Manage Members and Contacts - all permissions
 * @permissionScopeId SCOPE.DC-CONTACTS-MEGA.MANAGE-MEMBERS-CONTACTS
 * @permissionId CONTACTS_SCHEMA.VIEW
 * @applicableIdentity APP
 * @fqn com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.QueryExtendedFields
 */
export function queryExtendedFields() {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[0];
    return queryBuilder({
        func: async (payload) => {
            const reqOpts = ambassadorWixContactsV4ExtendedField.queryExtendedFields(payload);
            sideEffects?.onSiteCall?.();
            try {
                const result = await httpClient.request(reqOpts);
                sideEffects?.onSuccess?.(result);
                return result;
            }
            catch (err) {
                sideEffects?.onError?.(err);
                throw err;
            }
        },
        requestTransformer: (query) => {
            const args = [query, {}];
            return renameKeysFromSDKRequestToRESTRequest({
                ...args?.[1],
                query: args?.[0],
            });
        },
        responseTransformer: ({ data, }) => {
            const transformedData = renameKeysFromRESTResponseToSDKResponse(data);
            return {
                items: transformedData?.fields,
                pagingMetadata: transformedData?.pagingMetadata,
            };
        },
        errorTransformer: (err) => {
            const transformedError = sdkTransformError(err, {
                spreadPathsToArguments: {},
                explicitPathsToArguments: { query: '$[0]' },
                singleArgumentUnchanged: false,
            });
            throw transformedError;
        },
        pagingMethod: 'OFFSET',
        transformationPaths: {},
    });
}
//# sourceMappingURL=contacts-v4-extended-field-extended-fields.universal.js.map